#!/usr/bin/env node
import { program } from 'commander';
import debug from 'debug';
import dotenv from 'dotenv-extended';
import PgBoss from 'pg-boss';
import dev from './commandDev.js';
import run from './commandRun.js';
import enqueue from './enqueue.js';
import receive from './receive.js';

dotenv.load();

const log = debug('catirpel');
debug.enable('catirpel*');

program.version('0.128.0');

program
  .command('dev <caterpillarPath> <message...>')
  .description('Develop a caterpillar')
  .action((caterpillarPath, message) => {
    dev(
      caterpillarPath,
      message
        .map(x => x.split('='))
        .map(([key, ...value]) => ({ [key]: value.join('=') }))
        .reduce((acc, x) => ({ ...acc, ...x }), {})
    );
  });

program
  .command('run <caterpillarsRoot>')
  .description('Run caterpillars')
  .action(caterpillarsRoot => {
    run(caterpillarsRoot);
  });

program
  .command('enqueue <caterpillar>')
  .description('Enqueue messages')
  .action(async caterpillar => {
    const message = receive();
    const messages = Array.isArray(message) ? message : [message];
    const boss = new PgBoss({});
    await boss.start();
    await Promise.all(messages.map(x => enqueue(boss, caterpillar, x)));
    process.exit(0);
  });

program
  .command('reset [caterpillar]')
  .description('Delete queues')
  .action(async caterpillar => {
    const boss = new PgBoss({});
    boss.on('error', error => {
      log('queue error', error);
    });
    await boss.start();
    if (caterpillar) {
      log('deleting queue for', caterpillar);
      await boss.deleteQueue(`catirpel:${caterpillar}`);
    } else {
      log('clearing storage');
      await boss.clearStorage();
    }
    process.exit(0);
  });

program.parse();
