import { chromium } from 'playwright';
import isDebug from './isDebug.js';

const withBrowserPage = async (url, callback) => {
  const browser = await chromium.launch({
    devtools: isDebug,
    headless: !isDebug,
  });
  const context = await browser.newContext(isDebug ? { viewport: null } : {});
  const page = await context.newPage();
  await page.goto(url);
  if (isDebug) {
    await page.$eval('body', x => {
      const script = document.createElement('script');
      script.innerHTML = `
        (async () => {
          await import('https://unpkg.com/@popperjs/core@2');
          await import('https://unpkg.com/tippy.js@6');
          tippy('[data-tippy-content]', { allowHTML: true });
        })();
      `;
      x.append(script);
      const style = document.createElement('style');
      style.innerHTML = `.catirpel-highlight {
        background-color: #ccc !important;
        border-radius: 4px !important;
        padding: 2px !important;
      }
      .catirpel-highlight.selected {
        background-color: orange !important;
      }`;
      x.append(style);
    });
  }
  await callback(page);
  if (!isDebug) {
    await context.close();
    await browser.close();
  }
};

export default withBrowserPage;
